Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(595)

Unified Diff: compiler/java/com/google/dart/compiler/resolver/Element.java

Issue 9695025: Fixes for previous CL review comments (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: compiler/java/com/google/dart/compiler/resolver/Element.java
diff --git a/compiler/java/com/google/dart/compiler/resolver/Element.java b/compiler/java/com/google/dart/compiler/resolver/Element.java
index 6416f4c82aa317f94fedb17b7f729232e46b812b..087a324089875fef88af45a0c40a00d92d22f664 100644
--- a/compiler/java/com/google/dart/compiler/resolver/Element.java
+++ b/compiler/java/com/google/dart/compiler/resolver/Element.java
@@ -26,9 +26,9 @@ public interface Element extends HasSourceInfo {
Modifiers getModifiers();
/**
* @return the innermost {@link Element} which declares this {@link Element}.
*/
- Element getEnclosingElement();
+ EnclosingElement getEnclosingElement();
/**
* @return location of the name in the declaration of this {@link Element}.
@@ -26,9 +26,9 @@ public interface Element extends HasSourceInfo {
Modifiers getModifiers();
/**
- * @return the innermost {@link Element} which declares this {@link Element}.
+ * @return the innermost {@link EnclosingElement} which encloses this {@link Element}.
*/

Powered by Google App Engine
This is Rietveld 408576698